==> finix-4.0.0.tar.gz: finix-4.0.0/finix/model/create_fee_request.py <==
"""
    Finix API

    The version of the OpenAPI document: 2022-02-01
    Contact: support@finixpayments.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from finix.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    OpenApiModel
)
from finix.exceptions import ApiAttributeError


def lazy_import():
    from finix.model.currency import Currency
    from finix.model.tags import Tags
    globals()['Currency'] = Currency
    globals()['Tags'] = Tags


class CreateFeeRequest(ModelNormal):
    """

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ('fee_subtype',): {
            'CUSTOM': "CUSTOM",
        },
        ('fee_type',): {
            'CUSTOM': "CUSTOM",
        },
        ('linked_type',): {
            'APPLICATION': "APPLICATION",
            'PLATFORM': "PLATFORM",
            'SUBSCRIPTION': "SUBSCRIPTION",
            'TRANSFER': "TRANSFER",
        },
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'amount': (int,),  # noqa: E501
            'currency': (Currency,),  # noqa: E501
            'fee_subtype': (str,),  # noqa: E501
            'fee_type': (str,),  # noqa: E501
            'merchant_id': (str, none_type,),  # noqa: E501
            'label': (str,),  # noqa: E501
            'linked_id': (str,),  # noqa: E501
            'linked_type': (str,),  # noqa: E501
            'settlement_delay_days': (int, none_type,),  # noqa: E501
            'tags': (Tags,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'amount': 'amount',  # noqa: E501
        'currency': 'currency',  # noqa: E501
        'fee_subtype': 'fee_subtype',  # noqa: E501
        'fee_type': 'fee_type',  # noqa: E501
        'merchant_id': 'merchant_id',  # noqa: E501
        'label': 'label',  # noqa: E501
        'linked_id': 'linked_id',  # noqa: E501
        'linked_type': 'linked_type',  # noqa: E501
        'settlement_delay_days': 'settlement_delay_days',  # noqa: E501
        'tags': 'tags',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, amount, currency, merchant_id, *args, **kwargs):  # noqa: E501
        """CreateFeeRequest - a model defined in OpenAPI

        Args:
            amount (int): The total amount that will be debited in cents (e.g. 100 cents to debit $1.00).
            currency (Currency):
            merchant_id (str, none_type): The ID of the resource.

        Keyword Args:
            fee_subtype (str): Subtype of the fee. Set to **CUSTOM**.. defaults to "CUSTOM", must be one of ["CUSTOM", ]  # noqa: E501
            fee_type (str): The type of the fee. Must be set to **CUSTOM**.. defaults to "CUSTOM", must be one of ["CUSTOM", ]  # noqa: E501
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            label (str): The display name of the `Fee` that can be used for filtering purposes.. [optional]  # noqa: E501
            linked_id (str): ID of the linked resource. [optional]  # noqa: E501
            linked_type (str): The type of entity the fee is linked to (**null** by default).. [optional]  # noqa: E501
            settlement_delay_days (int, none_type): Delays in days, when the fee will be submitted for settlement.. [optional]  # noqa: E501
            tags (Tags): [optional]  # noqa: E501
        """

        fee_subtype = kwargs.get('fee_subtype', "CUSTOM")
        fee_type = kwargs.get('fee_type', "CUSTOM")
        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.amount = amount
        self.currency = currency
        self.fee_subtype = fee_subtype
        self.fee_type = fee_type
        self.merchant_id = merchant_id
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, amount, currency, merchant_id, *args, **kwargs):  # noqa: E501
        """CreateFeeRequest - a model defined in OpenAPI

        Args:
            amount (int): The total amount that will be debited in cents (e.g. 100 cents to debit $1.00).
            currency (Currency):
            merchant_id (str, none_type): The ID of the resource.

        Keyword Args:
            fee_subtype (str): Subtype of the fee. Set to **CUSTOM**.. defaults to "CUSTOM", must be one of ["CUSTOM", ]  # noqa: E501
            fee_type (str): The type of the fee. Must be set to **CUSTOM**.. defaults to "CUSTOM", must be one of ["CUSTOM", ]  # noqa: E501
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            label (str): The display name of the `Fee` that can be used for filtering purposes.. [optional]  # noqa: E501
            linked_id (str): ID of the linked resource. [optional]  # noqa: E501
            linked_type (str): The type of entity the fee is linked to (**null** by default).. [optional]  # noqa: E501
            settlement_delay_days (int, none_type): Delays in days, when the fee will be submitted for settlement.. [optional]  # noqa: E501
            tags (Tags): [optional]  # noqa: E501
        """

        fee_subtype = kwargs.get('fee_subtype', "CUSTOM")
        fee_type = kwargs.get('fee_type', "CUSTOM")
        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.amount = amount
        self.currency = currency
        self.fee_subtype = fee_subtype
        self.fee_type = fee_type
        self.merchant_id = merchant_id
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")

==> finix-5.0.0.tar.gz: finix-5.0.0/finix/model/create_fee_request.py <==
"""
    Finix API

    The version of the OpenAPI document: 2022-02-01
    Contact: support@finixpayments.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from finix.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    OpenApiModel
)
from finix.exceptions import ApiAttributeError


def lazy_import():
    from finix.model.currency import Currency
    from finix.model.tags import Tags
    globals()['Currency'] = Currency
    globals()['Tags'] = Tags


class CreateFeeRequest(ModelNormal):
    """

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ('fee_subtype',): {
            'CUSTOM': "CUSTOM",
        },
        ('fee_type',): {
            'CUSTOM': "CUSTOM",
        },
        ('linked_type',): {
            'APPLICATION': "APPLICATION",
            'PLATFORM': "PLATFORM",
            'SUBSCRIPTION': "SUBSCRIPTION",
            'TRANSFER': "TRANSFER",
        },
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'amount': (int,),  # noqa: E501
            'currency': (Currency,),  # noqa: E501
            'fee_subtype': (str,),  # noqa: E501
            'fee_type': (str,),  # noqa: E501
            'merchant_id': (str,),  # noqa: E501
            'label': (str,),  # noqa: E501
            'linked_id': (str,),  # noqa: E501
            'linked_type': (str,),  # noqa: E501
            'settlement_delay_days': (int, none_type,),  # noqa: E501
            'tags': (Tags,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'amount': 'amount',  # noqa: E501
        'currency': 'currency',  # noqa: E501
        'fee_subtype': 'fee_subtype',  # noqa: E501
        'fee_type': 'fee_type',  # noqa: E501
        'merchant_id': 'merchant_id',  # noqa: E501
        'label': 'label',  # noqa: E501
        'linked_id': 'linked_id',  # noqa: E501
        'linked_type': 'linked_type',  # noqa: E501
        'settlement_delay_days': 'settlement_delay_days',  # noqa: E501
        'tags': 'tags',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, amount, currency, merchant_id, *args, **kwargs):  # noqa: E501
        """CreateFeeRequest - a model defined in OpenAPI

        Args:
            amount (int): The total amount that will be debited in cents (e.g. 100 cents to debit $1.00).
            currency (Currency):
            merchant_id (str): The ID of the `Merchant` resource used to create the `Fee`.

        Keyword Args:
            fee_subtype (str): Subtype of the fee. Set to **CUSTOM**.. defaults to "CUSTOM", must be one of ["CUSTOM", ]  # noqa: E501
            fee_type (str): The type of the fee. Must be set to **CUSTOM**.. defaults to "CUSTOM", must be one of ["CUSTOM", ]  # noqa: E501
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            label (str): The display name of the `Fee` that can be used for filtering purposes.. [optional]  # noqa: E501
            linked_id (str): ID of the linked resource. [optional]  # noqa: E501
            linked_type (str): The type of entity the fee is linked to (**null** by default).. [optional]  # noqa: E501
            settlement_delay_days (int, none_type): Delays in days, when the `Transfer` the `Fee` creates will be submitted for settlement.. [optional]  # noqa: E501
            tags (Tags): [optional]  # noqa: E501
        """

        fee_subtype = kwargs.get('fee_subtype', "CUSTOM")
        fee_type = kwargs.get('fee_type', "CUSTOM")
        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.amount = amount
        self.currency = currency
        self.fee_subtype = fee_subtype
        self.fee_type = fee_type
        self.merchant_id = merchant_id
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, amount, currency, merchant_id, *args, **kwargs):  # noqa: E501
        """CreateFeeRequest - a model defined in OpenAPI

        Args:
            amount (int): The total amount that will be debited in cents (e.g. 100 cents to debit $1.00).
            currency (Currency):
            merchant_id (str): The ID of the `Merchant` resource used to create the `Fee`.

        Keyword Args:
            fee_subtype (str): Subtype of the fee. Set to **CUSTOM**.. defaults to "CUSTOM", must be one of ["CUSTOM", ]  # noqa: E501
            fee_type (str): The type of the fee. Must be set to **CUSTOM**.. defaults to "CUSTOM", must be one of ["CUSTOM", ]  # noqa: E501
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            label (str): The display name of the `Fee` that can be used for filtering purposes.. [optional]  # noqa: E501
            linked_id (str): ID of the linked resource. [optional]  # noqa: E501
            linked_type (str): The type of entity the fee is linked to (**null** by default).. [optional]  # noqa: E501
            settlement_delay_days (int, none_type): Delays in days, when the `Transfer` the `Fee` creates will be submitted for settlement.. [optional]  # noqa: E501
            tags (Tags): [optional]  # noqa: E501
        """

        fee_subtype = kwargs.get('fee_subtype', "CUSTOM")
        fee_type = kwargs.get('fee_type', "CUSTOM")
        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.amount = amount
        self.currency = currency
        self.fee_subtype = fee_subtype
        self.fee_type = fee_type
        self.merchant_id = merchant_id
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")
